@@ -55,12 +55,12 @@ import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 
+import com.openexchange.java.Strings;
 import com.openexchange.mobile.api.facade.auth.SessionData;
 import com.openexchange.mobile.api.facade.connectors.BaseConnector;
 import com.openexchange.mobile.api.facade.connectors.RequestConfiguration;
 import com.openexchange.mobile.api.facade.connectors.responses.FoldersResponseMto;
 import com.openexchange.mobile.api.facade.models.Folder;
-import com.openexchange.mobile.api.facade.utils.StringUtils;
 
 import org.apache.http.client.methods.HttpUriRequest;
 import org.apache.http.client.methods.RequestBuilder;
@@ -103,10 +103,10 @@ public class AllFoldersConnector extends BaseConnector<FoldersResponseMto> {
         builder.addParameter("action", "allVisible");
         builder.addParameter("content_type", "mail");
         builder.addParameter("columns", "1,20,300,302,316,306");
-        if (!StringUtils.isEmpty(rootFolderId)) {
+        if (!Strings.isEmpty(rootFolderId)) {
             builder.addParameter("root", rootFolderId);
         }
-        if (!StringUtils.isEmpty(language)) {
+        if (!Strings.isEmpty(language)) {
             builder.addParameter("language", language);
         }
         return builder.build();
