@@ -59,6 +59,8 @@ import javax.ws.rs.core.MediaType;
 import javax.ws.rs.core.Response;
 
 import com.openexchange.mobile.api.facade.auth.SessionData;
+import com.openexchange.mobile.api.facade.configuration.ConfigurationHelper;
+import com.openexchange.mobile.api.facade.configuration.HostConfiguration;
 import com.openexchange.mobile.api.facade.endpoints.responses.ctos.ConfigCto;
 import com.openexchange.mobile.api.facade.models.Config;
 import com.openexchange.mobile.api.facade.services.ConfigService;
@@ -80,7 +82,9 @@ public class ConfigEndpoint {
     public Response getConfiguration(@Context HttpServletRequest request) {
         SessionData sessionData = RequestUtil.getSessionData(request);
         log.info("Retrieving configuration");
-        Config config = configService.getConfig(sessionData);
+        HostConfiguration hostConfiguration = ConfigurationHelper.getConfiguration(request);
+        Config config = configService.getConfig(sessionData)
+                .withProperties(hostConfiguration.getCustomProperties());
         ConfigCto configCto = new ConfigCto(config);
         return RequestUtil.jsonResponse(configCto);
     }
