@@ -57,6 +57,7 @@ import javax.ws.rs.Consumes;
 import javax.ws.rs.DELETE;
 import javax.ws.rs.GET;
 import javax.ws.rs.POST;
+import javax.ws.rs.PUT;
 import javax.ws.rs.Path;
 import javax.ws.rs.Produces;
 import javax.ws.rs.core.Context;
@@ -67,12 +68,15 @@ import com.openexchange.mobile.api.facade.auth.SessionData;
 import com.openexchange.mobile.api.facade.endpoints.requests.ExamineFolderRequestBody;
 import com.openexchange.mobile.api.facade.endpoints.requests.FolderCreateRequestBody;
 import com.openexchange.mobile.api.facade.endpoints.requests.FolderRequestBody;
+import com.openexchange.mobile.api.facade.endpoints.requests.FolderUpdateRequestBody;
 import com.openexchange.mobile.api.facade.endpoints.responses.AccountsResponseBody;
 import com.openexchange.mobile.api.facade.endpoints.responses.CreateFolderResponseBody;
 import com.openexchange.mobile.api.facade.endpoints.responses.ExamineFolderResponseBody;
+import com.openexchange.mobile.api.facade.endpoints.responses.UpdatedFolderResponseBody;
 import com.openexchange.mobile.api.facade.models.Account;
 import com.openexchange.mobile.api.facade.models.CreatedFolder;
 import com.openexchange.mobile.api.facade.models.ExamineResult;
+import com.openexchange.mobile.api.facade.models.UpdatedFolder;
 import com.openexchange.mobile.api.facade.services.FoldersService;
 import com.openexchange.mobile.api.facade.utils.JacksonUtil;
 import com.openexchange.mobile.api.facade.utils.RequestUtil;
@@ -86,26 +90,41 @@ import lombok.extern.slf4j.Slf4j;
 @Slf4j
 public class FoldersEndpoint {
 
+    private static final String FIELD_FOLDER_ID = "folderId";
+
     private final FoldersService foldersService;
 
     @POST
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
     public Response createFolder(@Context HttpServletRequest request, String rawRequestBody) {
-        log.info("Create folder");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Create folder");
         FolderCreateRequestBody requestBody = JacksonUtil.parse(rawRequestBody, FolderCreateRequestBody.class);
         CreatedFolder folder = foldersService.createFolder(sessionData, requestBody.getParentFolderId(), requestBody.getName());
         CreateFolderResponseBody responseBody = new CreateFolderResponseBody(folder);
         return RequestUtil.jsonResponse(201, responseBody);
     }
 
+    @PUT
+    @Consumes(MediaType.APPLICATION_JSON)
+    @Produces(MediaType.APPLICATION_JSON)
+    public Response updateFolder(@Context HttpServletRequest request, String rawRequestBody) {
+        SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Update folder");
+        FolderUpdateRequestBody requestBody = JacksonUtil.parse(rawRequestBody, FolderUpdateRequestBody.class);
+        RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
+        UpdatedFolder folder = foldersService.updateFolder(sessionData, requestBody.getFolderId(), requestBody.getNewParentFolderId(), requestBody.getNewName());
+        UpdatedFolderResponseBody responseBody = new UpdatedFolderResponseBody(folder);
+        return RequestUtil.jsonResponse(200, responseBody);
+    }
+
     @DELETE
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
     public Response deleteFolder(@Context HttpServletRequest request, String rawRequestBody) {
-        log.info("Delete folder");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Delete folder");
         FolderRequestBody requestBody = JacksonUtil.parse(rawRequestBody, FolderRequestBody.class);
         foldersService.deleteFolder(sessionData, requestBody.getFolderId());
         return RequestUtil.emptyJsonResponse();
@@ -116,8 +135,8 @@ public class FoldersEndpoint {
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
     public Response expungeFolder(@Context HttpServletRequest request, String rawRequestBody) {
-        log.info("Clear folder");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Clear folder");
         FolderRequestBody requestBody = JacksonUtil.parse(rawRequestBody, FolderRequestBody.class);
         foldersService.clearFolder(sessionData, requestBody.getFolderId());
         return RequestUtil.emptyJsonResponse();
@@ -127,8 +146,8 @@ public class FoldersEndpoint {
     @Path("/mail")
     @Produces(MediaType.APPLICATION_JSON)
     public Response getAllMailFolders(@Context HttpServletRequest request) {
-        log.info("Retrieve mail folders");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Retrieve mail folders");
         String language = RequestUtil.getLanguage(request);
         List<Account> accounts = foldersService.getAllMailFolders(sessionData, language);
         AccountsResponseBody accountsResponseBody = new AccountsResponseBody(accounts);
@@ -140,8 +159,8 @@ public class FoldersEndpoint {
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
     public Response examineFolder(@Context HttpServletRequest request, String rawRequestBody) {
-        log.info("Examine folder");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Examine folder");
         ExamineFolderRequestBody requestBody = JacksonUtil.parse(rawRequestBody, ExamineFolderRequestBody.class);
         ExamineResult result = foldersService.examineFolder(sessionData, requestBody.getFolderId(), requestBody.getValidity(), requestBody.getNext());
         ExamineFolderResponseBody responseBody = new ExamineFolderResponseBody(result);
