@@ -50,6 +50,7 @@
 package com.openexchange.mobile.api.facade.endpoints.responses.ctos;
 
 import java.util.List;
+import java.util.Map;
 
 import com.fasterxml.jackson.annotation.JsonInclude;
 import com.fasterxml.jackson.annotation.JsonProperty;
@@ -88,6 +89,9 @@ public class ConfigCto {
     @JsonInclude(JsonInclude.Include.NON_EMPTY)
     List<CapabilityCto> capabilities;
 
+    @JsonInclude(JsonInclude.Include.NON_EMPTY)
+    Map<String, String> properties;
+
     @JsonInclude(JsonInclude.Include.NON_DEFAULT)
     boolean multipleAccountsEnabled;
 
@@ -97,6 +101,7 @@ public class ConfigCto {
         maxAttachmentSize = config.getMaxAttachmentSize();
         deleteDraftOnTransport = config.isDeleteDraftOnTransport();
         capabilities = ListUtil.map(config.getCapabilities(), capabilitiesMapFunction);
+        properties = config.getProperties();
         multipleAccountsEnabled = config.isMultipleAccountsEnabled();
     }
 
