@@ -49,6 +49,9 @@
 
 package com.openexchange.mobile.api.facade.exceptions;
 
+import java.util.Collections;
+import java.util.List;
+
 import javax.ws.rs.WebApplicationException;
 import javax.ws.rs.core.Response;
 import javax.ws.rs.core.Response.Status;
@@ -121,7 +124,19 @@ public class ApiFacadeException extends WebApplicationException {
         } else if (isRedirect(code)) {
             return redirect(error);
         }
-        return create(Status.BAD_REQUEST, code, responseBody.getErrorDescription());
+        List<String> categories = getCategories(responseBody.getCategories());
+        return create(Status.BAD_REQUEST, code, null, responseBody.getErrorDescription(), categories);
+    }
+
+    @SuppressWarnings("unchecked")
+    private static List<String> getCategories(Object categories) {
+        if (categories instanceof String) {
+            return Collections.<String>singletonList((String) categories);
+        } else if (categories instanceof List) {
+            return (List<String>) categories;
+        } else {
+            return null;
+        }
     }
 
     private static boolean isMaximumNumberOfSessionsExceeded(String code) {
@@ -218,15 +233,15 @@ public class ApiFacadeException extends WebApplicationException {
     }
 
     private static ApiFacadeException create(Status status, int errorCode, Exception cause, String message) {
-        return create(status, String.valueOf(errorCode), cause, message);
+        return create(status, String.valueOf(errorCode), cause, message, null);
     }
 
     private static ApiFacadeException create(Status status, String errorCode, String message) {
-        return create(status, errorCode, null, message);
+        return create(status, errorCode, null, message, null);
     }
 
-    private static ApiFacadeException create(Status status, String errorCode, Exception cause, String message) {
-        String responseBody = JacksonUtil.toString(new AbstractResponseBody(errorCode, message));
+    private static ApiFacadeException create(Status status, String errorCode, Exception cause, String message, List<String> categories) {
+        String responseBody = JacksonUtil.toString(new AbstractResponseBody(errorCode, message, categories));
         Response response = Response.status(status).entity(responseBody).build();
         return new ApiFacadeException(errorCode, cause, message, response);
     }
