@@ -70,8 +70,7 @@ public class Capability {
 
     public Capability(CapabilityDataMto capabilityData) {
         id = capabilityData.getId();
-        Map<String, Object> attributesMto = capabilityData.getAttributes();
-        attributes = attributesMto != null ? attributesMto : Collections.<String, Object>emptyMap();
+        attributes = capabilityData.getAttributes();
     }
 
 }
