@@ -81,10 +81,14 @@ public enum Priority {
 
     public static Priority valueOf(int value) {
         Priority priority = Cache.store.get(value);
-        if (priority == null) {
-            throw new IllegalArgumentException("No enum constant matches value: " + value);
+        return priority == null ? Priority.MEDIUM : priority;
+    }
+
+    public static Priority valueOf(Integer value) {
+        if (value == null) {
+            return NOPRIORITY;
         }
-        return priority;
+        return Priority.valueOf(value.intValue());
     }
 
 }
