@@ -73,7 +73,10 @@ public class ConfigService {
         ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
         Config configuration = retrieveConfiguration(connectorFactory, sessionData);
         List<Capability> capabilities = retrieveCapabilities(connectorFactory, sessionData);
-        return configuration.withCapabilities(capabilities);
+        boolean isMultipleAccountsEnabled = sessionData.getConfiguration().isReturnNonPrimaryAccounts();
+        return configuration
+                .withCapabilities(capabilities)
+                .withMultipleAccountsEnabled(isMultipleAccountsEnabled);
     }
 
     public SessionData addConfiguration(SessionData sessionData) {
@@ -95,6 +98,10 @@ public class ConfigService {
         List<Capability> capabilities = new ArrayList<>(remoteCapabilities.size() + 1);
         capabilities.addAll(remoteCapabilities);
         capabilities.add(new Capability("facade_accounts_sync"));
+        capabilities.add(new Capability("facade_accounts_crud"));
+        if (sessionData.getConfiguration().isReturnNonPrimaryAccounts()) {
+            capabilities.add(new Capability("facade_multiple_accounts_enabled"));
+        }
         return capabilities;
     }
 
