@@ -49,6 +49,7 @@
 
 package com.openexchange.mobile.api.facade.services;
 
+import java.util.ArrayList;
 import java.util.List;
 
 import com.openexchange.mobile.api.facade.auth.SessionData;
@@ -76,6 +77,7 @@ import com.openexchange.mobile.api.facade.models.MailFlags;
 import com.openexchange.mobile.api.facade.models.MailIds;
 import com.openexchange.mobile.api.facade.models.MailThread;
 import com.openexchange.mobile.api.facade.utils.AttachmentUtil;
+import com.openexchange.mobile.api.facade.utils.FilterFunction;
 import com.openexchange.mobile.api.facade.utils.ListUtil;
 import com.openexchange.mobile.api.facade.utils.MailTransformations;
 import com.openexchange.mobile.api.facade.utils.MailUtil;
@@ -95,6 +97,13 @@ public class MailsService {
         }
     };
 
+    private final MapFunction<MailThread, String> mailIdMapFunction = new MapFunction<MailThread, String>() {
+        @Override
+        public String map(MailThread mail) {
+            return mail.getRootMailId();
+        }
+    };
+
     public List<MailThread> getStubs(SessionData sessionData, String folderId, boolean threaded) {
         ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
         List<MailThread> mailThreads;
@@ -150,6 +159,17 @@ public class MailsService {
         return MailUtil.wrapAsThreads(mails);
     }
 
+    public List<MailThread> getNewStubs(SessionData sessionData, String folderId, long lastReceivedDate, boolean threaded) {
+        List<MailThread> allStubs = getStubs(sessionData, folderId, threaded);
+        List<MailThread> newStubs = new ArrayList<>();
+        for (MailThread thread : allStubs) {
+            if (thread.getLastReceivedDate() >= lastReceivedDate) {
+                newStubs.add(thread);
+            }
+        }
+        return newStubs;
+    }
+
     public List<Mail> getEnvelopes(SessionData sessionData, String folderId, List<String> mailIds) {
         ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
         EnvelopesConnector connector = connectorFactory.getEnvelopesConnector(sessionData, folderId, mailIds);
@@ -157,6 +177,20 @@ public class MailsService {
         return EnvelopesConnector.map(responseBody.getData());
     }
 
+    public List<Mail> getNewEnvelopes(SessionData sessionData, String folderId, final long lastReceivedDate) {
+        ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
+        List<MailThread> stubs = getStubsWithoutThreading(connectorFactory, sessionData, folderId);
+        List<String> mailIds = ListUtil.map(ListUtil.filter(stubs, new FilterFunction<MailThread>() {
+            @Override
+            public boolean filter(MailThread thread) {
+                return thread.getLastReceivedDate() >= lastReceivedDate;
+            }
+        }), mailIdMapFunction);
+        EnvelopesConnector connector = connectorFactory.getEnvelopesConnector(sessionData, folderId, mailIds);
+        ArrayDataResponseMto responseBody = connector.execute();
+        return EnvelopesConnector.map(responseBody.getData());
+    }
+
     public Mail getMail(SessionData sessionData, String folderId, String mailId, int maximumTeaserLength) {
         ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
         GetMailConnector connector = connectorFactory.getGetMailConnector(sessionData, folderId, mailId);
