@@ -100,7 +100,7 @@ public class MailTransformations {
         if (!ListUtil.isEmpty(contentParts) && contentParts.size() > 1) {
             parts = ListUtil.remove(parts, contentParts);
             String content = combineContentParts(contentParts);
-            Attachment part = new Attachment("generated", Disposition.INLINE, contentType, content.length(), content, null, null, null, null);
+            Attachment part = new Attachment("generated", Disposition.INLINE, contentType, content.length(), content, false, null, null, null);
             parts.add(0, part);
         } else if (!ListUtil.isEmpty(contentParts) && contentParts.size() == 1) {
             Attachment part = contentParts.get(0);
